# Generated by Django 2.2.18 on 2021-02-23 21:54

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_dashboard', '0006_auto_20210219_1255'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='dashboard',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control']},
        ),
    ]
