# Generated by Django 2.2.18 on 2021-02-19 11:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_dashboard', '0005_auto_20200619_1102'),
    ]

    operations = [
        migrations.AddField(
            model_name='dashboard',
            name='background',
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name='dashboard',
            name='target',
            field=models.CharField(default='default', max_length=20),
        ),
    ]
